#include <iostream>

#include "rendering/FileTexture.h"
#include "rendering/Framebuffer.h"
#include "rendering/Window.h"
#include "tests/ArrayListTests.h"
#include "tests/ArrayTests.h"
#include "tests/BitArrayTests.h"
#include "tests/BufferTests.h"
#include "tests/ClockTests.h"
#include "tests/ColorTests.h"
#include "tests/FrustumTests.h"
#include "tests/HashMapTests.h"
#include "tests/ListTests.h"
#include "tests/MatrixStackTests.h"
#include "tests/MatrixTests.h"
#include "tests/NetworkTests.h"
#include "tests/PNGReaderTests.h"
#include "tests/PlaneTests.h"
#include "tests/QuaternionTests.h"
#include "tests/RandomTests.h"
#include "tests/RingBufferTests.h"
#include "tests/SplitStringTests.h"
#include "tests/StackTests.h"
#include "tests/StringBufferTests.h"
#include "tests/TypedBufferTests.h"
#include "tests/UniquePointerTests.h"
#include "tests/UtilsTests.h"
#include "tests/VectorTests.h"
#include "utils/Logger.h"

int main(int argAmount, char** args) {
    if(argAmount < 2) {
        std::cout << "missing path to images\n";
        return 0;
    }
    ArrayTests::test();
    ArrayListTests::test();
    HashMapTests::test();
    ListTests::test();
    BitArrayTests::test();
    StringBufferTests::test();
    RandomTests::test();
    RingBufferTests::test();
    SplitStringTests::test();
    VectorTests::test();
    MatrixTests::test();
    StackTests::test();
    MatrixStackTests::test();
    PlaneTests::test();
    FrustumTests::test();
    QuaternionTests::test();
    UtilsTests::test();
    ColorTests::test();
    ClockTests::test();
    PNGReaderTests::test(args[1]);
    BufferTests::test();
    TypedBufferTests::test();
    UniquePointerTests::test();
    NetworkTests::test();

    struct Game {
        bool isRunning() {
            return true;
        }

        void tick() {
        }

        void render(float) {
        }
    };

    TextInput* input = nullptr;
    Size size(800, 480);
    WindowOptions options(4, 3, size, false, "Test");
    Window w(input, options);
    if(w.getError().has()) {
        std::cout << w.getError().message << "\n";
        return 0;
    }
    Game game;
    w.run(game, 10'000'000);

    LOG_ERROR("HI");
    LOG_ERROR(StringBuffer<50>(" dfgdf hi"));
    LOG_WARNING("HI");
    LOG_WARNING(StringBuffer<50>(" dfgdf hi"));
    LOG_INFO("HI");
    LOG_INFO(StringBuffer<50>(" dfgdf hi"));
    LOG_DEBUG("HI");
    LOG_DEBUG(StringBuffer<50>(" dfgdf hi"));

    return 0;
}